@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: kwatch.cpp,v 1.7 2001/01/30 11:40:55 mj Exp $
+ * $Id: kwatch.cpp,v 1.9 2001/09/12 15:58:21 mj Exp $
  *
  * Class for kwatch application
  *
@@ -102,8 +102,6 @@ kwatch::kwatch()
 
 kwatch::~kwatch()
 {
-//    fprintf(stderr, "~kwatch()\n");
-    
     if(m_popup)
 	delete m_popup;
     if(m_log)
@@ -123,9 +121,12 @@ void kwatch::setupActions()
     KStdAction::preferences(this, SLOT(optionsPreferences()),
 			    actionCollection());
 
-    new KAction(            i18n("Reopen files"), 0,
+    new KAction(            i18n("Reopen files"), "reload", 0,
 			    this, SLOT(reopen()),
 			    actionCollection(), "file_reopen");
+    new KAction(            i18n("Clear"), "editdelete", 0,
+			    this, SLOT(clear()),
+			    actionCollection(), "edit_clear");
     m_menubarAction
 	= new KToggleAction(i18n("Show Menubar"), 0,
 			    this, SLOT(optionsShowMenubar()),
@@ -143,18 +144,21 @@ void kwatch::setupActions()
 
 void kwatch::quit()
 {
-//    fprintf(stderr, "kwatch::quit()\n");
-
     saveConfig();
     kapp->quit();
 }
 
 
 
+void kwatch::clear()
+{
+    m_log->clear();
+}
+
+
+
 void kwatch::reopen()
 {
-//    fprintf(stderr, "kwatch::reopen()\n");
-
     m_log->reopen();
 }
 
@@ -176,12 +180,6 @@ void kwatch::saveConfig()
 void kwatch::saveProperties(KConfig *config)
 {
     m_cf.geometry = QRect(pos(), size());
-//     fprintf(stderr, "kwatch: frame geometry=%d,%d,%d,%d\n",
-// 	    m_cf.geometry.x(), m_cf.geometry.y(),
-// 	    m_cf.geometry.width(), m_cf.geometry.height());
-
-//     m_cf.geometry = geometry();
-    
     m_cf.save(config);
 }
 
@@ -201,8 +199,6 @@ void kwatch::readProperties(KConfig *config)
 
 void kwatch::closeEvent(QCloseEvent *e)
 {
-//     fprintf(stderr, "closeEvent()\n");
-
     saveConfig();
     KMainWindow::closeEvent(e);
 }
@@ -211,8 +207,6 @@ void kwatch::closeEvent(QCloseEvent *e)
 
 void kwatch::optionsShowMenubar()
 {
-//    fprintf(stderr, "kdslmon::optionsShowMenubar()\n");
-
     if (m_menubarAction->isChecked())
         menuBar()->show();
     else
@@ -232,13 +226,10 @@ void kwatch::optionsConfigureKeys()
 
 void kwatch::optionsPreferences()
 {
-//    fprintf(stderr, "kwatch::optionsPreferences()\n");
-
     m_prefs = new kwatchPrefs(this, m_cf);
     
     if(m_prefs->exec())
     {
-//	fprintf(stderr, "kwatch::optionsPreferences() - exec\n");
 	m_prefs->setMainConf();
 	m_log->updateConf();
     }
