@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: kwatchconf.cpp,v 1.4 2001/01/18 21:57:30 mj Exp $
+ * $Id: kwatchconf.cpp,v 1.5 2001/09/12 15:56:51 mj Exp $
  *
  * Configuration parameters of the application
  *
@@ -58,6 +58,10 @@ void kwatchConf::save(KConfig *config)
     config->writeEntry("MaxLines"  , maxlines);
     config->writeEntry("BufSize"   , bufsize);
     config->writeEntry("ShowMenu"  , showmenu);
+    config->writeEntry("EnableCall", enableCall);
+    config->writeEntry("EnableLog" , enableLog);
+    config->writeEntry("SoundCall" , soundCall);
+    config->writeEntry("SoundLog"  , soundLog);
     config->sync();
 }
 
@@ -73,13 +77,18 @@ void kwatchConf::read(KConfig *config)
 //    fprintf(stderr, "kwatchConf::read()\n");
 
     config->setGroup("Conf");
-    geometry = config->readRectEntry ("Geometry"  , &def_geometry);
-    logfiles = config->readListEntry ("LogFiles"  , ':');
-    font     = config->readFontEntry ("Font"      , &def_font);
-    fg       = config->readColorEntry("Foreground", &def_fg);
-    bg       = config->readColorEntry("Background", &def_bg);
-    logdir   = config->readPathEntry ("LogDir"    , DEFAULT_LOGDIR);
-    maxlines = config->readNumEntry  ("MaxLines"  , DEFAULT_MAXLINES);
-    bufsize  = config->readNumEntry  ("BufSize"   , DEFAULT_BUFSIZE);
-    showmenu = config->readBoolEntry ("ShowMenu"  , DEFAULT_SHOWMENU);
+    geometry   = config->readRectEntry ("Geometry"  , &def_geometry);
+    logfiles   = config->readListEntry ("LogFiles"  , ':');
+    font       = config->readFontEntry ("Font"      , &def_font);
+    fg         = config->readColorEntry("Foreground", &def_fg);
+    bg         = config->readColorEntry("Background", &def_bg);
+    logdir     = config->readPathEntry ("LogDir"    , DEFAULT_LOGDIR);
+    maxlines   = config->readNumEntry  ("MaxLines"  , DEFAULT_MAXLINES);
+    bufsize    = config->readNumEntry  ("BufSize"   , DEFAULT_BUFSIZE);
+    showmenu   = config->readBoolEntry ("ShowMenu"  , DEFAULT_SHOWMENU);
+    enableCall = config->readBoolEntry ("EnableCall", DEFAULT_ENABLECALL);
+    soundCall  = config->readPathEntry ("SoundCall");
+    enableLog  = config->readBoolEntry ("EnableLog" ,DEFAULT_ENABLELOG);
+    soundLog   = config->readPathEntry ("SoundLog");
+    
 }
