@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: kwatchconf.h,v 1.3 2001/01/18 21:57:30 mj Exp $
+ * $Id: kwatchconf.h,v 1.4 2001/09/12 15:56:51 mj Exp $
  *
  * Configuration parameters of the application
  *
@@ -65,7 +65,10 @@ public:
     int         maxlines;
     int         bufsize;
     bool        showmenu;
-
+    bool	enableCall;
+    bool	enableLog;
+    QString	soundCall;
+    QString	soundLog;
     
 public:
     // read/save config
@@ -88,6 +91,8 @@ public:
 #define DEFAULT_MAXLINES	500
 #define DEFAULT_BUFSIZE		1024
 #define DEFAULT_SHOWMENU	true
+#define DEFAULT_ENABLECALL	true
+#define DEFAULT_ENABLELOG	true
 
 
 #endif /**KWATCHCONF_H**/
