@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: main.cpp,v 0.11 2001/04/21 21:55:45 mj Exp $
+ * $Id: main.cpp,v 0.15 2002/05/09 15:37:46 mj Exp $
  *
  * kwatch main()
  *
@@ -47,7 +47,7 @@
 
 
 static const char *description = I18N_NOOP("KDE Log File Viewer");
-static const char *version = "2.0.1";
+static const char *version = "2.3.0";
 
 
 
@@ -56,8 +56,9 @@ int main(int argc, char **argv)
     KAboutData about("kwatch",
 		     I18N_NOOP("kwatch"),
 		     version, description,
-		     KAboutData::License_GPL, "(C) 2000 Martin Junius");
-    about.addAuthor("Martin Junius", 0, "mj@m-j-s.net");
+		     KAboutData::License_GPL, "(C) 2000-2001 Martin Junius");
+    about.addAuthor("Martin Junius", "Main Developer",
+		    "mj@m-j-s.net", "http://www.m-j-s.net/kde/");
     KCmdLineArgs::init(argc, argv, &about);
     KApplication app;
 
