@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: prefs.cpp,v 0.10 2001/01/13 21:47:27 mj Exp $
+ * $Id: prefs.cpp,v 0.11 2001/09/12 15:56:51 mj Exp $
  *
  * Class for kwatch preferences dialog
  *
@@ -48,6 +48,7 @@
 #include <ksimpleconfig.h>
 #include <klocale.h>
 #include <kfiledialog.h>
+#include <klineedit.h>
 
 #include "prefs.h"
 
@@ -89,8 +90,12 @@ kwatchPrefs::kwatchPrefs(QWidget *parent, kwatchConf &cf)
     : KDialogBase(Tabbed, i18n("Preferences"), Ok|Cancel, Ok, parent),
       m_cf(cf), m_copy(cf)
 {
-    QVBox *page;
+    QVBox       *page;
+    QLabel      *l;
+    QWidget     *p;
+    QGridLayout *g;
 
+    
     /* Page Files ************************************************************/
     page = addVBoxPage(i18n("Files"));
 
@@ -119,7 +124,7 @@ kwatchPrefs::kwatchPrefs(QWidget *parent, kwatchConf &cf)
     hl->activate();
 
     /* Page Window ***********************************************************/
-    page = addVBoxPage(i18n("Window"));
+    page = addVBoxPage(i18n("Appearance"));
 
     QWidget * viewtab = new QWidget(page);
 
@@ -157,10 +162,37 @@ kwatchPrefs::kwatchPrefs(QWidget *parent, kwatchConf &cf)
 
     hl->activate();
 
-    /* Page Parameters *******************************************************/
-    page = addVBoxPage(i18n("Parameters"));
+    //----- Tab with Alert settings and sound files --------------------------
+    page = addVBoxPage(i18n("Alerts"));
+    p = new QWidget(page);
+    g = new QGridLayout(p, 5, 2, 10);
+    g->setColStretch(0, 1);
+    g->setRowStretch(5, 1);
+
+    m_alertCall = new QCheckBox(i18n("Check for incoming ISDN calls"), p);
+    g->addMultiCellWidget(m_alertCall, 0, 0, 0, 1, 0);
+
+    l = new QLabel(i18n("Sound:"), p);
+    l->setAlignment(AlignRight|AlignVCenter);
+    g->addWidget(l, 1, 0);
+    m_soundCall = new KURLRequester(p);
+    m_soundCall->fileDialog()->setFilter("*.wav");
+    g->addWidget(m_soundCall, 1, 1);
+
+    m_alertLog = new QCheckBox(i18n("Check for IP connection attempts (firewall log)"), p);
+    g->addMultiCellWidget(m_alertLog, 2, 2, 0, 1, 0);
+
+    l = new QLabel(i18n("Sound:"), p);
+    l->setAlignment(AlignRight|AlignVCenter);
+    g->addWidget(l, 3, 0);
+    m_soundLog = new KURLRequester(p);
+    m_soundLog->fileDialog()->setFilter("*.wav");
+    g->addWidget(m_soundLog, 3, 1);
+
+    //----- Tab with some more options ---------------------------------------
+    page = addVBoxPage(i18n("Options"));
     QWidget *paramtab = new QWidget(page);
-    QGridLayout *g = new QGridLayout(paramtab, 3, 2, 10);
+    g = new QGridLayout(paramtab, 3, 2, 10);
     
     QLabel *label;
     
@@ -178,7 +210,8 @@ kwatchPrefs::kwatchPrefs(QWidget *parent, kwatchConf &cf)
     g->addWidget(m_param2, 1, 1);
     connect(m_param2, SIGNAL(valueChanged(int)), SLOT(changeParam2(int)));
 
-    /*************************************************************************/
+    //------------------------------------------------------------------------
+
     updateConf();
 }
 
@@ -190,15 +223,11 @@ kwatchPrefs::~kwatchPrefs() {
 
 void kwatchPrefs::changeParam1(int val)
 {
-//    fprintf(stderr, "kwatchPrefs::changeParam1(%d)\n", val);
-
     m_copy.maxlines = val;
 }
 
 void kwatchPrefs::changeParam2(int val)
 {
-//    fprintf(stderr, "kwatchPrefs::changeParam2(%d)\n", val);
-
     m_copy.bufsize = val;
 }
 
@@ -223,6 +252,11 @@ void kwatchPrefs::updateConf()
 
     m_param1->setValue(m_copy.maxlines);
     m_param2->setValue(m_copy.bufsize);
+
+    m_alertCall->setChecked(m_copy.enableCall);
+    m_alertLog ->setChecked(m_copy.enableLog);
+    m_soundCall->lineEdit()->setText(m_copy.soundCall);
+    m_soundLog ->lineEdit()->setText(m_copy.soundLog);
 }
 
 
@@ -231,8 +265,6 @@ void kwatchPrefs::addFile()
 {
     QString s = KFileDialog::getOpenFileName(m_copy.logdir, QString::null,
 					     this, i18n("Add Log File")   );
-//    fprintf(stderr, "kwatchPrefs::addFile() s=%s\n",
-//	    (const char *)s);
 
     if(!s.isNull() && !s.isEmpty()) 
     {
@@ -288,6 +320,11 @@ void kwatchPrefs::chooseBackground()
 void kwatchPrefs::setMainConf()
 {
     m_cf = m_copy;
+
+    m_cf.enableCall = m_alertCall->isChecked();
+    m_cf.enableLog  = m_alertLog ->isChecked();
+    m_cf.soundCall  = m_soundCall->lineEdit()->text();
+    m_cf.soundLog   = m_soundLog ->lineEdit()->text();
 }
 
 
